pitchtools.HarmonicDiatonicInterval
===================================

.. inheritance-diagram:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.cents

   .. note:: Inherited from :py:class:`pitchtools._Interval <abjad.tools.pitchtools._Interval._Interval._Interval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.diatonic_interval_class

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.harmonic_counterpoint_interval

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.harmonic_diatonic_interval_class

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.interval_class

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.interval_string

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.melodic_diatonic_interval_ascending

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.melodic_diatonic_interval_descending

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.number

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.quality_string

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.semitones

.. autoattribute:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.staff_spaces

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__abs__

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__eq__

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__float__

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__ge__

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__gt__

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__hash__

   .. note:: Inherited from :py:class:`pitchtools._Interval <abjad.tools.pitchtools._Interval._Interval._Interval>`

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__int__

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__le__

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__lt__

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__ne__

   .. note:: Inherited from :py:class:`pitchtools._DiatonicInterval <abjad.tools.pitchtools._DiatonicInterval._DiatonicInterval._DiatonicInterval>`

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__repr__

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.pitchtools.HarmonicDiatonicInterval.HarmonicDiatonicInterval.HarmonicDiatonicInterval.__str__
